%global srcname typer-cli
%global forgeurl https://github.com/tiangolo/%{srcname}
%global tag %{version}

%bcond_without completions

Name:           python-%{srcname}
Version:        0.0.12
%forgemeta
Release:        1%{?dist}
Summary:        Run Typer scripts with completion, without creating a package

License:        MIT
URL:            https://typer.tiangolo.com/%{srcname}/
Source0:        %{forgesource}
# Hand-written downstream man page in groff_man(7) format:
Source1:        typer.1

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros

# Extra BR’s that could not be generated, from [tool.poetry.dev-dependencies]
# in pyproject.toml. We do not include linters, formatters, or optional
# coverage analysis tools, just the things we need to run the tests. In some
# cases, we must loosen the version specifications.

# pytest = "^6.0.1"
BuildRequires:  python3dist(pytest) >= 6.0.1
# pytest-cov = "^2.8.1"
BuildRequires:  (python3dist(pytest-cov) >= 2.8.1 with python3dist(pytest-cov) < 3.0)

# BR’s for shell completion
#
# The shells for which we generate completions should be determined by those
# supported by click. Some other packages with completion support which are
# useful to reference are git, creds, and pipx.
#
# These shells are mentioned in the man page; please update that if adding
# support for another shell.
%if %{with completions}
BuildRequires:  pkgconfig(bash-completion)
%global bashcompdir %(pkg-config --variable=completionsdir bash-completion 2>/dev/null)
%global bashcomproot %(dirname %{bashcompdir} 2>/dev/null)
BuildRequires:  zsh
%global zshcompdir %{_datadir}/zsh/site-functions
%global zshcomproot %(dirname %{zshcompdir} 2>/dev/null)
BuildRequires:  pkgconfig(fish)
%global fishcompdir %(pkg-config --variable=completionsdir fish 2>/dev/null)
%global fishcomproot %(dirname %{fishcompdir} 2>/dev/null)
%endif

%global modname %(echo '%{srcname}' | tr '-' '_')

%global common_description %{expand:
Run Typer scripts with completion, without having to create a package, using
Typer CLI.

There is an optional utility tool called Typer CLI, additional to Typer itself.

Its main feature is to provide ✨ completion ✨ in the Terminal for your own
small programs built with Typer.

…without you having to create a complete installable Python package.

It’s probably most useful if you have a small custom Python script using Typer
(maybe as part of some project), for some small tasks, and it’s not
complex/important enough to create a whole installable Python package for it
(something to be installed with pip).

In that case, you can install Typer CLI, and run your program with the typer
command in your Terminal, and it will provide completion for your script.

You can also use Typer CLI to generate Markdown documentation for your own
Typer programs 📝.

Documentation: https://typer.tiangolo.com/typer-cli/

Source Code for Typer CLI: https://github.com/tiangolo/typer-cli}

%description %{common_description}


%generate_buildrequires
%pyproject_buildrequires -r


%package -n     python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %{common_description}


%prep
%forgeautosetup -p1
cp -p %{SOURCE1} .


%build
%pyproject_wheel

%if %{with completions}
(
  # Temporary local install
  PYTEMP="${PWD}/%{_vpath_builddir}/pytemp"
  if [ -n "${PYTHONPATH-}" ]; then PYTHONPATH="${PYTHONPATH}:"; fi
  export PYTHONPATH="${PYTHONPATH-}${PYTEMP}"
  # Based on %%pyproject_wheel
  %{__python3} -m pip install --target="${PYTEMP}" \
      --no-deps --use-pep517 --no-build-isolation \
      --disable-pip-version-check --no-clean --progress-bar off --verbose \
      %{_pyproject_wheeldir}/*.whl

  # Generate shell completions.
  for sh in bash zsh fish
  do
    {
      "${sh}" -l <<EOF
env PYTHONPATH="${PYTHONPATH}" %{__python3} -m %{modname} --show-completion
EOF
    } | tee "%{_vpath_builddir}/%{name}.${sh}"
  done

  rm -rf "${PYTEMP}"
)
%endif


%install
%pyproject_install
%pyproject_save_files %{modname}
install -D -t '%{buildroot}%{_mandir}/man1' -p -m 0644 'typer.1'
%if %{with completions}
install -p -m 0644 -D -t '%{buildroot}%{bashcompdir}' \
    '%{_vpath_builddir}/%{name}.bash'
install -p -m 0644 -D '%{_vpath_builddir}/%{name}.zsh' \
    '%{buildroot}%{zshcompdir}/_%{name}'
install -p -m 0644 -D -t '%{buildroot}%{fishcompdir}' \
    '%{_vpath_builddir}/%{name}.fish'
%endif


%check
%pytest


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE
%doc README.md
%doc release-notes.md
%{_bindir}/typer
%{_mandir}/man1/typer.1*
%if %{with completions}
# Note that it is standard in Fedora for packages providing shell completions
# to co-own the completions directory in lieu of having a runtime dependency on
# the relevant shell completions package.
%{bashcomproot}
%{zshcomproot}
%{fishcomproot}
%endif


%changelog
* Wed Jul  7 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.0.12-1
- Update to 0.0.12
- Drop python-typer-cli-0.0.11-no-importlib_metadata.patch, as the
  importlib-metadata backport dependency is now removed upstream entirely.

* Fri Jun 18 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.0.11-1
- Initial package
